@@ -1,10 +1,10 @@
-/* $Id: strtonum.cpp 75931 2012-01-26 15:51:44Z fmehnert $ */
+/* $Id: strtonum.cpp 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - String To Number Conversion.
  */
 
 /*
- * Copyright (C) 2006-2007 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include <iprt/string.h>
 #include "internal/iprt.h"
 
@@ -36,9 +36,9 @@
 #include <iprt/err.h>
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 /** 8-bit char -> digit. */
 static const unsigned char g_auchDigits[256] =
 {
@@ -971,17 +971,22 @@ RT_EXPORT_SYMBOL(RTStrToInt8);
 
 RTDECL(int) RTStrConvertHexBytes(char const *pszHex, void *pv, size_t cb, uint32_t fFlags)
 {
+    size_t      cbDst;
+    uint8_t    *pbDst;
+    const char *pszSrc;
+
     AssertPtrReturn(pszHex, VERR_INVALID_POINTER);
     AssertReturn(!fFlags, VERR_INVALID_PARAMETER);
 
-    size_t      cbDst   = cb;
-    uint8_t    *pbDst   = (uint8_t *)pv;
-    const char *pszSrc  = pszHex;
+    cbDst  = cb;
+    pbDst  = (uint8_t *)pv;
+    pszSrc = pszHex;
     for (;;)
     {
         /* Pick the next two digit from the string. */
         char ch = *pszSrc++;
         unsigned char uchDigit1 = g_auchDigits[(unsigned char)ch];
+        unsigned char uchDigit2;
         if (uchDigit1 >= 16)
         {
             if (!ch)
@@ -993,7 +998,7 @@ RTDECL(int) RTStrConvertHexBytes(char const *pszHex, void *pv, size_t cb, uint32
         }
 
         ch = *pszSrc++;
-        unsigned char uchDigit2 = g_auchDigits[(unsigned char)ch];
+        uchDigit2 = g_auchDigits[(unsigned char)ch];
         if (uchDigit2 >= 16)
             return VERR_UNEVEN_INPUT;
 
