@@ -1,10 +1,10 @@
-/* $Id: alloc-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: alloc-r0drv-linux.c 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - Memory Allocation, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include "the-linux-kernel.h"
 #include "internal/iprt.h"
 #include <iprt/mem.h>
@@ -37,7 +37,7 @@
 #include "r0drv/alloc-r0drv.h"
 
 
-#if defined(RT_ARCH_AMD64) || defined(DOXYGEN_RUNNING)
+#if (defined(RT_ARCH_AMD64) || defined(DOXYGEN_RUNNING)) && !defined(RTMEMALLOC_EXEC_HEAP)
 # if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23)
 /**
  * Starting with 2.6.23 we can use __get_vm_area and map_vm_area to allocate
@@ -63,9 +63,9 @@
 #endif
 
 
-/*******************************************************************************
-*   Structures and Typedefs                                                    *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Structures and Typedefs                                                                                                      *
+*********************************************************************************************************************************/
 #ifdef RTMEMALLOC_EXEC_VM_AREA
 /**
  * Extended header used for headers marked with RTMEMHDR_FLAG_EXEC_VM_AREA.
@@ -87,14 +87,15 @@ typedef RTMEMLNXHDREX *PRTMEMLNXHDREX;
 #endif
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 #ifdef RTMEMALLOC_EXEC_HEAP
 /** The heap. */
 static RTHEAPSIMPLE g_HeapExec = NIL_RTHEAPSIMPLE;
 /** Spinlock protecting the heap. */
 static RTSPINLOCK   g_HeapExecSpinlock = NIL_RTSPINLOCK;
+#endif
 
 
 /**
@@ -103,8 +104,10 @@ static RTSPINLOCK   g_HeapExecSpinlock = NIL_RTSPINLOCK;
  */
 DECLHIDDEN(void) rtR0MemExecCleanup(void)
 {
+#ifdef RTMEMALLOC_EXEC_HEAP
     RTSpinlockDestroy(g_HeapExecSpinlock);
     g_HeapExecSpinlock = NIL_RTSPINLOCK;
+#endif
 }
 
 
@@ -120,11 +123,13 @@ DECLHIDDEN(void) rtR0MemExecCleanup(void)
  * The API only accept one single donation.
  *
  * @returns IPRT status code.
+ * @retval  VERR_NOT_SUPPORTED if the code isn't enabled.
  * @param   pvMemory    Pointer to the memory block.
  * @param   cb          The size of the memory block.
  */
 RTR0DECL(int) RTR0MemExecDonate(void *pvMemory, size_t cb)
 {
+#ifdef RTMEMALLOC_EXEC_HEAP
     int rc;
     AssertReturn(g_HeapExec == NIL_RTHEAPSIMPLE, VERR_WRONG_ORDER);
 
@@ -136,10 +141,13 @@ RTR0DECL(int) RTR0MemExecDonate(void *pvMemory, size_t cb)
             rtR0MemExecCleanup();
     }
     return rc;
+#else
+    RT_NOREF_PV(pvMemory); RT_NOREF_PV(cb);
+    return VERR_NOT_SUPPORTED;
+#endif
 }
 RT_EXPORT_SYMBOL(RTR0MemExecDonate);
 
-#endif /* RTMEMALLOC_EXEC_HEAP */
 
 
 #ifdef RTMEMALLOC_EXEC_VM_AREA
