@@ -1,10 +1,10 @@
-/* $Id: semevent-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
+/* $Id: semevent-r0drv-linux.c 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - Single Release Event Semaphores, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #define RTSEMEVENT_WITHOUT_REMAPPING
 #include "the-linux-kernel.h"
 #include "internal/iprt.h"
@@ -43,9 +43,9 @@
 #include "internal/magics.h"
 
 
-/*******************************************************************************
-*   Structures and Typedefs                                                    *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Structures and Typedefs                                                                                                      *
+*********************************************************************************************************************************/
 /**
  * Linux event semaphore.
  */
@@ -72,6 +72,8 @@ RTDECL(int)  RTSemEventCreate(PRTSEMEVENT phEventSem)
 RTDECL(int)  RTSemEventCreateEx(PRTSEMEVENT phEventSem, uint32_t fFlags, RTLOCKVALCLASS hClass, const char *pszNameFmt, ...)
 {
     PRTSEMEVENTINTERNAL pThis;
+    IPRT_LINUX_SAVE_EFL_AC();
+    RT_NOREF_PV(hClass); RT_NOREF_PV(pszNameFmt);
 
     AssertReturn(!(fFlags & ~(RTSEMEVENT_FLAGS_NO_LOCK_VAL | RTSEMEVENT_FLAGS_BOOTSTRAP_HACK)), VERR_INVALID_PARAMETER);
     Assert(!(fFlags & RTSEMEVENT_FLAGS_BOOTSTRAP_HACK) || (fFlags & RTSEMEVENT_FLAGS_NO_LOCK_VAL));
@@ -86,6 +88,7 @@ RTDECL(int)  RTSemEventCreateEx(PRTSEMEVENT phEventSem, uint32_t fFlags, RTLOCKV
     init_waitqueue_head(&pThis->Head);
 
     *phEventSem = pThis;
+    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemEventCreate);
@@ -117,6 +120,8 @@ DECLINLINE(void) rtR0SemEventLnxRelease(PRTSEMEVENTINTERNAL pThis)
 
 RTDECL(int)  RTSemEventDestroy(RTSEMEVENT hEventSem)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
     /*
      * Validate input.
      */
@@ -134,6 +139,8 @@ RTDECL(int)  RTSemEventDestroy(RTSEMEVENT hEventSem)
     Assert(!waitqueue_active(&pThis->Head));
     wake_up_all(&pThis->Head);
     rtR0SemEventLnxRelease(pThis);
+
+    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemEventDestroy);
@@ -141,6 +148,8 @@ RT_EXPORT_SYMBOL(RTSemEventDestroy);
 
 RTDECL(int)  RTSemEventSignal(RTSEMEVENT hEventSem)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
     /*
      * Validate input.
      */
@@ -156,6 +165,7 @@ RTDECL(int)  RTSemEventSignal(RTSEMEVENT hEventSem)
     wake_up(&pThis->Head);
 
     rtR0SemEventLnxRelease(pThis);
+    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemEventSignal);
@@ -174,6 +184,7 @@ static int rtR0SemEventLnxWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, uint6
                                PCRTLOCKVALSRCPOS pSrcPos)
 {
     int rc;
+    RT_NOREF_PV(pSrcPos);
 
     /*
      * Validate the input.
@@ -194,6 +205,7 @@ static int rtR0SemEventLnxWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, uint6
         /*
          * We have to wait.
          */
+        IPRT_LINUX_SAVE_EFL_AC();
         RTR0SEMLNXWAIT Wait;
         rc = rtR0SemLnxWaitInit(&Wait, fFlags, uTimeout, &pThis->Head);
         if (RT_SUCCESS(rc))
@@ -230,6 +242,7 @@ static int rtR0SemEventLnxWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, uint6
             rtR0SemLnxWaitDelete(&Wait);
             IPRT_DEBUG_SEMS_STATE_RC(pThis, 'E', rc);
         }
+        IPRT_LINUX_RESTORE_EFL_AC();
     }
 
     rtR0SemEventLnxRelease(pThis);
